@@ -1004,7 +1004,8 @@ class OvercloudInventoryDiscover(KayobeAnsibleMixin, VaultMixin, Command):
                                      "overcloud-inventory-discover"))
         # If necessary, allocate IP addresses for the discovered hosts.
         self.run_kayobe_playbook(parsed_args,
-                                 _get_playbook_path("ip-allocation"))
+                                 _get_playbook_path("ip-allocation"),
+                                 limit="overcloud")
         # Now populate the Kolla Ansible inventory.
         self.generate_kolla_ansible_config(parsed_args, service_config=False)
 
